# Changelog

* The following workspace dependencies were updated
  * dependencies
    * accesskit_unix bumped from 0.7.0 to 0.7.1

* The following workspace dependencies were updated
  * dependencies
    * accesskit_windows bumped from 0.16.0 to 0.16.1
    * accesskit_unix bumped from 0.7.1 to 0.7.2

* The following workspace dependencies were updated
  * dependencies
    * accesskit_unix bumped from 0.7.2 to 0.7.3

* The following workspace dependencies were updated
  * dependencies
    * accesskit_windows bumped from 0.16.1 to 0.16.2

* The following workspace dependencies were updated
  * dependencies
    * accesskit bumped from 0.12.2 to 0.12.3
    * accesskit_windows bumped from 0.16.2 to 0.16.3
    * accesskit_macos bumped from 0.11.0 to 0.11.1
    * accesskit_unix bumped from 0.7.3 to 0.7.4

* The following workspace dependencies were updated
  * dependencies
    * accesskit_unix bumped from 0.7.4 to 0.7.5

* The following workspace dependencies were updated
  * dependencies
    * accesskit_windows bumped from 0.16.3 to 0.16.4

## [0.1.1](https://github.com/AccessKit/accesskit/compare/accesskit_python-v0.1.0...accesskit_python-v0.1.1) (2024-01-06)


### Bug Fixes

* Decrease minimum Python version to 3.8 for Python bindings ([#334](https://github.com/AccessKit/accesskit/issues/334)) ([3725373](https://github.com/AccessKit/accesskit/commit/3725373658bf2475cf3e1341b2e5fcefada576bd))

## 0.1.0 (2024-01-03)


### Features

* Add Python bindings ([#269](https://github.com/AccessKit/accesskit/issues/269)) ([52560da](https://github.com/AccessKit/accesskit/commit/52560da1c1480f1a37a27906b24b518a5fa03249))


### Dependencies

* The following workspace dependencies were updated
  * dependencies
    * accesskit bumped from 0.12.1 to 0.12.2
    * accesskit_windows bumped from 0.15.1 to 0.16.0
    * accesskit_macos bumped from 0.10.1 to 0.11.0
    * accesskit_unix bumped from 0.6.2 to 0.7.0
